﻿using Blahblah.FlowerStory.Server.Data;
using Microsoft.AspNetCore.Mvc;

namespace Blahblah.FlowerStory.Server.Controller;

/// <summary>
/// 图片相关服务
/// </summary>
[Produces("image/png")]
[Route("photo")]
public class ImageController : BaseController
{
    /// <inheritdoc/>
    public ImageController(FlowerDatabase database, ILogger<BaseController>? logger = null) : base(database, logger)
    {
    }

    /// <summary>
    /// 请求用户头像
    /// </summary>
    /// <remarks>
    /// 请求示例：
    /// 
    ///     GET /photo/avatar
    ///     Authorization: authorization id
    /// 
    /// </remarks>
    /// <returns>认证通过则显示用户头像</returns>
    /// <response code="200">返回头像</response>
    /// <response code="401">认证失败</response>
    /// <response code="404">未找到头像</response>
    [Route("avatar", Name = "getAvatar")]
    [ProducesResponseType(StatusCodes.Status200OK)]
    [ProducesResponseType(StatusCodes.Status401Unauthorized)]
    [ProducesResponseType(StatusCodes.Status404NotFound)]
    [HttpGet]
    public ActionResult GetUserAvatar()
    {
        var (result, token) = CheckToken();
        if (result != null)
        {
            return result;
        }
        if (token == null)
        {
            return Unauthorized();
        }
        var avatar = QueryUserAvatar(token.UserId);
        if (avatar == null)
        {
            return NotFound();
        }
        return File(avatar, "image/png");
    }
}
